(function() {
  var capitalize, generateToken, parseDomainString, tokenizeDomain, _;

  _ = require('lodash');

  capitalize = function(string) {
    var host;
    host = string.charAt(0).toUpperCase() + string.slice(1).toLowerCase();
    return host != null ? typeof host.replace === "function" ? host.replace(/\W/g, '') : void 0 : void 0;
  };

  generateToken = function(domainGroups) {
    var tmp;
    if (domainGroups == null) {
      domainGroups = [];
    }
    tmp = domainGroups.map(function(f) {
      return capitalize(f);
    });
    if (tmp.length === 1) {
      return tmp[0];
    }
    tmp = tmp.join('');
    return tmp != null ? tmp.replace(/[^a-zA-Z0-9 ]/g, '') : void 0;
  };

  tokenizeDomain = function(domain) {
    var results, splitDomain, splitPort, tokenized, _splitDomain;
    if (domain == null) {
      domain = '';
    }
    if (!domain) {
      return {};
    }
    tokenized = domain.toString().toLowerCase().trim();
    splitPort = tokenized.split(':');
    if (!splitPort.length) {
      return {};
    }
    splitDomain = splitPort[0].split(/\./gi).reverse();
    domain = _.clone(splitDomain).splice(0, splitDomain.length - 1).reverse().join('.');
    if (!domain) {
      domain = splitDomain[0];
    }
    _splitDomain = _.clone(splitDomain).reverse();
    results = {};
    if (splitDomain.length > 2) {
      results.sld = _splitDomain[1];
      results.prefix = _splitDomain[0];
    } else {
      results.prefix = null;
      results.sld = _splitDomain[0];
    }
    results.suffix = splitDomain[0];
    if (splitPort.length >= 2) {
      results.port = _.last(splitPort);
    } else {
      results.port = null;
    }
    results.idn = _splitDomain.join('.');
    results.groups = _splitDomain;
    results.token = generateToken(_splitDomain);
    return results;
  };

  parseDomainString = function(hostname, referer) {
    var data, parsed, refererParsed;
    parsed = /^((http|https|ftp|ftps|news|ssh|sftp|gopher):[\/]{2,})?([^\/]+)/.exec(hostname);
    refererParsed = /^((http|https|ftp|ftps|news|ssh|sftp|gopher):[\/]{2,})?([^\/]+)/.exec(referer);
    data = {
      url: parsed[0],
      protocolFormat: parsed[1],
      protocol: parsed[2],
      name: parsed[3],
      uri: parsed['input']
    };
    data.host = tokenizeDomain(data.name);
    if (refererParsed) {
      data.referer = tokenizeDomain(refererParsed[3]);
    }
    data.token = data.host.token;
    data.level = function(number) {
      return data.idn.split(/\./gi).reverse()[parseInt(number) - 1];
    };
    data.toString = function() {
      return data.name;
    };
    return data;
  };

  module.exports = function(request) {
    return parseDomainString(request.hostname.toLowerCase().trim(), request.get('Referer'));
  };

}).call(this);
