describe 'Unit test', ->
  domains = [
    '127.0.0.1'
    'https://developer.domainname.org:8080/en-US/docs/'
    'http://domainname.com:4080/api/bdd/'
    'http://adfadsf-dsdsdsd_fdgf.domainname.com:8030/tutorials/sfadfd-4543534-43543-435-asdfds-4353-24696'
    'http://test.domainname.com.uk.pl/'
  ]

  domainParse = require '../../src/domainParse/index'

  describe 'request', ->
    it 'should parse 127.0.0.1', ->
      parse = domainParse
        hostname: domains[0]
        get: -> domains[0]

      expect(parse.url).to.equal '127.0.0.1'
      expect(parse.name).to.equal '127.0.0.1'
      expect(parse.uri).to.equal '127.0.0.1'
      expect(parse.token).to.equal '127001'

      expect(parse.host).to.exist
      expect(parse.host.sld).to.equal '0'
      expect(parse.host.prefix).to.equal '127'
      expect(parse.host.suffix).to.equal '1'
      expect(parse.host.port).to.equal null
      expect(parse.host.idn).to.equal '127.0.0.1'
      expect(parse.host.groups).to.exist
      expect(parse.host.token).to.equal '127001'

      expect(parse.referer).to.exist
      expect(parse.referer.sld).to.equal '0'
      expect(parse.referer.prefix).to.equal '127'
      expect(parse.referer.suffix).to.equal '1'
      expect(parse.referer.port).to.equal null
      expect(parse.referer.idn).to.equal '127.0.0.1'
      expect(parse.referer.groups).to.exist
      expect(parse.referer.token).to.equal '127001'

    it 'should parse developer.domainname.org', ->
      parse = domainParse
        hostname: domains[1]
        get: -> domains[1]

      expect(parse.url).to.equal 'https://developer.domainname.org:8080'
      expect(parse.protocolFormat).to.equal 'https://'
      expect(parse.protocol).to.equal 'https'

      expect(parse.name).to.equal 'developer.domainname.org:8080'
      expect(parse.uri).to.equal 'https://developer.domainname.org:8080/en-us/docs/'
      expect(parse.token).to.equal 'DeveloperDomainnameOrg'

      expect(parse.host).to.exist
      expect(parse.host.sld).to.equal 'domainname'
      expect(parse.host.prefix).to.equal 'developer'
      expect(parse.host.suffix).to.equal 'org'
      expect(parse.host.port).to.equal '8080'
      expect(parse.host.idn).to.equal 'developer.domainname.org'
      expect(parse.host.groups).to.exist
      expect(parse.host.token).to.equal 'DeveloperDomainnameOrg'

      expect(parse.referer).to.exist
      expect(parse.referer.sld).to.equal 'domainname'
      expect(parse.referer.prefix).to.equal 'developer'
      expect(parse.referer.suffix).to.equal 'org'
      expect(parse.referer.port).to.equal '8080'
      expect(parse.referer.idn).to.equal 'developer.domainname.org'
      expect(parse.referer.groups).to.exist
      expect(parse.referer.token).to.equal 'DeveloperDomainnameOrg'

    it 'should parse domainname.com:4080', ->
      parse = domainParse
        hostname: domains[2]
        get: -> domains[2]

      expect(parse.url).to.equal 'http://domainname.com:4080'
      expect(parse.name).to.equal 'domainname.com:4080'
      expect(parse.uri).to.equal 'http://domainname.com:4080/api/bdd/'
      expect(parse.token).to.equal 'DomainnameCom'
      expect(parse.host.sld).to.equal 'domainname'
      expect(parse.host.prefix).to.equal null
      expect(parse.host.suffix).to.equal 'com'
      expect(parse.host.port).to.equal '4080'
      expect(parse.host.idn).to.equal 'domainname.com'
      expect(parse.host.token).to.equal 'DomainnameCom'

    it 'should parse adfadsf-dsdsdsd_fdgf.domainname.com:8030', ->
      parse = domainParse
        hostname: domains[3]
        get: -> domains[3]

      expect(parse.url).to.equal 'http://adfadsf-dsdsdsd_fdgf.domainname.com:8030'
      expect(parse.name).to.equal 'adfadsf-dsdsdsd_fdgf.domainname.com:8030'
      expect(parse.uri).to.equal 'http://adfadsf-dsdsdsd_fdgf.domainname.com:8030/tutorials/sfadfd-4543534-43543-435-asdfds-4353-24696'
      expect(parse.token).to.equal 'AdfadsfdsdsdsdfdgfDomainnameCom'
      expect(parse.host.sld).to.equal 'domainname'
      expect(parse.host.prefix).to.equal 'adfadsf-dsdsdsd_fdgf'
      expect(parse.host.suffix).to.equal 'com'
      expect(parse.host.port).to.equal '8030'
      expect(parse.host.idn).to.equal 'adfadsf-dsdsdsd_fdgf.domainname.com'
      expect(parse.host.token).to.equal 'AdfadsfdsdsdsdfdgfDomainnameCom'

    it 'should parse test.domainname.com.uk.pl', ->
      parse = domainParse
        hostname: domains[4]
        get: -> domains[4]

      expect(parse.url).to.equal 'http://test.domainname.com.uk.pl'
      expect(parse.name).to.equal 'test.domainname.com.uk.pl'
      expect(parse.uri).to.equal 'http://test.domainname.com.uk.pl/'
      expect(parse.token).to.equal 'TestDomainnameComUkPl'
      expect(parse.host.sld).to.equal 'domainname'
      expect(parse.host.prefix).to.equal 'test'
      expect(parse.host.suffix).to.equal 'pl'
      expect(parse.host.port).to.equal null
      expect(parse.host.idn).to.equal 'test.domainname.com.uk.pl'
      expect(parse.host.token).to.equal 'TestDomainnameComUkPl'
